
#version 130              // delete this line if using GLSL 1.2
precision mediump float;  // delete this line if using GLSL 1.2

// uniform shader-parameters
uniform vec3 light_position;
uniform vec4 light_color;
uniform vec4 ambient_color;
uniform vec4 item_color;

uniform sampler2D colorTexture;
uniform sampler2D lightmapTexture;

uniform int lightmaps_enabled;
uniform int render_level;

// fragment-shader input variables
in vec4 frag_color;
in vec3 world_normal;
in vec4 world_position;
in vec2 texture_coordinates;
in vec2 light_map;
in vec4 depth_value;

in vec3 eye_normal;
in vec4 eye_position;
in vec3 light_dir;
in vec3 half_vec;

// fragment-shader output variable (-> stored in the frame-buffer, i.e. "the pixel you see")
out vec4 outData1;
out vec4 outData2;
                   
void main()
{
    // renormalize and homogenize input variables
    vec3 normal = normalize(world_normal);
    vec3 position = world_position.xyz / world_position.w;

    vec3 normal_norm = normalize(eye_normal);	
    vec3 light_dir_norm = normalize(light_dir);   
    vec3 half_vec_norm = normalize(half_vec);	 

    // calculate the light-direction
    vec3 light_dir = normalize(light_position - position);

    // calculate texture
    vec4 texel = texture2D(colorTexture, texture_coordinates);

    // lightmap
    vec4 lm = texture2D(lightmapTexture, light_map);

    // calculate lighting
    vec4 ambient = ambient_color *  frag_color;
    vec4 diffuse = frag_color * light_color * max(0.0, dot(normal, light_dir));
    vec4 null = vec4(0.0, 0.0, 0.0, 0.0);

    vec4 texel_new;

    if(!all(equal(texel, vec4(0.0, 0.0, 0.0, 0.0)))){

        if (lightmaps_enabled == 1)
                texel_new = texel * lm;
        else
                texel_new = texel;

        ambient = ambient * texel_new;
        diffuse = diffuse * texel_new;
    }
    
    // write color to output
    //if (!all(equal(lm, vec4(0.0, 0.0, 0.0, 0.0)))) {
    //    fragColor = (diffuse + ambient) * lm;
    //} else {
    //    fragColor =  diffuse + ambient;
    //}

    if (render_level == 0) {
	ambient = ambient_color *  frag_color;
	//diffuse = frag_color * light_color * max(0.0, dot(normal, light_dir));
	
	diffuse = frag_color * light_color * max(dot(normal_norm, light_dir_norm), 0.0);
	vec4 specular = frag_color * light_color * pow(max(dot(normal_norm, half_vec_norm), 0.0), 32.00f);	
	//vec4 specular = vec4(pow(max(dot(normal_norm, half_vec_norm), 0.0), 2.0f), 0.0f, 0.0f, 1.0f);

        outData1 = ambient + diffuse + specular;
        outData2 = depth_value * vec4(0.0f, 0.0f, -0.001f, 1.0);

	//if (normal_norm.z > 0.90 && normal_norm.x < 0.1 && normal_norm.y < 0.1) {
	//	outData1 = vec4(1.0f, 1.0f, -0.001f, 1.0f); 
	//	outData2 = depth_value * vec4(0.0f, 0.0f, -0.001f, 1.0);
	//}
    } else if (render_level == 2) {
	outData1 = frag_color;
	outData2 = depth_value * vec4(0.0f, 0.0f, -0.001f, 1.0); 
    } else if (render_level == 3) {
	//ambient = ambient_color *  frag_color;
	//diffuse = frag_color * light_color * max(dot(normal_norm, light_dir_norm), 0.0);
	//vec4 specular = frag_color * light_color * pow(max(dot(normal_norm, half_vec_norm), 0.0), 32.00f);

	outData1 = frag_color * item_color;
	outData2 = depth_value * vec4(0.0f, 0.0f, -0.001f, 1.0); 
    } else {
        outData1 = texel_new;
        outData2 = depth_value * vec4(0.0f, 0.0f, -0.001f, 1.0);
    }
}
