
#version 130              // delete this line if using GLSL 1.2
precision mediump float;  // delete this line if using GLSL 1.2

// uniform shader-parameters
uniform mat4 perspective;
uniform mat4 view;
uniform mat4 model;

// uniform shader-parameters
uniform vec3 light_position;
uniform vec4 light_color;
uniform vec4 ambient_color;

// vertex-shader input variables
in vec4 vertex;
in vec4 color;
in vec3 normal;
in vec2 texture;
in vec2 lightmap;

// vertex-shader output variables (passed to fragment-shader)
out vec4 frag_color;
out vec3 world_normal;
out vec4 world_position;
out vec2 texture_coordinates;
out vec2 light_map;
out vec4 depth_value;

out vec3 eye_normal;
out vec4 eye_position;
out vec3 light_dir;
out vec3 half_vec;

void main()
{
    // transform normal into world space
    vec4 normal4 = vec4(normal, 0.0f);
    world_normal = (model * normal4).xyz;

    // Vertex Normal -> Eye Space
    mat3x3 normalMatrix = mat3x3(view * model);
    vec3 eyenormal = normalize(normalMatrix * normal);
    eye_normal = eyenormal;

    // Lightmap
    light_map = lightmap;

    // transform vertex to world-space
    world_position = model * vertex;

    // Vertex Position -> Eye Space
    vec4 eyeposition = view * model * vec4(vertex.xyz, 1.0f);
    eye_position = eyeposition;    

    // just pass color to fragment-shader
    frag_color = color;

    //pass texture coordinates to fragment-shader
    texture_coordinates = texture;

    // depth value for Depth of Field Effekt
    depth_value = view * model * vertex; 

    vec3 lightPos = (view * vec4(light_position, 1.0f)).xyz;
    light_dir = lightPos - eyeposition.xyz;	
    
        
    //light_dir = -(eyeposition.xyz);	// SIM

    // Eye Vektor
    vec3 eyeVector = -(eyeposition.xyz);
    half_vec = normalize(light_dir + eyeVector);
    //half_vec = -(eyeposition.xyz);	// SIM

     light_dir = normalize(light_dir);
    
    // transform vertex down the pipeline
    gl_Position = perspective * view * model * vertex;
}
